@@ -12,7 +12,7 @@ import (
 	"strings"
 
 	"github.com/siderolabs/gen/xslices"
-	"gopkg.in/yaml.v3"
+	"go.yaml.in/yaml/v4"
 )
 
 //go:embed presets/*.yaml
